"use strict";

var chalk, copyAndReplace, dotFilePath, fs, getDirectories, isDirectory, localModule, path, run, ruuiCliModule, ruuiModule, templateExclusions, walk, yarn;
fs = require("fs");
path = require("path");
({
  chalk
} = require("../util/modules"));
({
  ruuiModule,
  localModule,
  ruuiCliModule,
  isDirectory,
  getDirectories,
  dotFilePath,
  templateExclusions
} = require("../util/helper"));
walk = require("../util/walk");
copyAndReplace = require("../util/copyAndReplace");
yarn = require("../util/yarn");

run = function (argv, config, args) {
  var addon, addonPath, availableAddons, currentAddonPath, dependencies, dependenciesPath, devDependencies, devDependenciesPath, localAddonPath, templates, yarnVersion;
  addon = args.addon;
  addonPath = path.resolve(ruuiModule("cli", "addons"));
  localAddonPath = path.resolve(localModule("cli", "addons"));

  if (fs.existsSync(localAddonPath)) {
    addonPath = localAddonPath;
  }

  availableAddons = getDirectories(addonPath).map(function (source) {
    return path.relative(addonPath, source);
  }).filter(function (name) {
    return name !== "core";
  });
  yarnVersion = yarn.getYarnVersionIfAvailable() && yarn.isProjectUsingYarn(process.cwd());
  templates = require("../util/templates");

  if (!(availableAddons.indexOf(addon) >= 0)) {
    console.log(chalk.gray("failed to install, addon ".concat(chalk.red(addon), " does not exists, available addons:")));
    console.log(chalk.green("[".concat(availableAddons.join(", "), "]")));
    return;
  }

  dependencies = {};
  devDependencies = {};
  currentAddonPath = path.resolve(addonPath, addon);
  dependenciesPath = path.resolve(currentAddonPath, "dependencies.json");
  devDependenciesPath = path.resolve(currentAddonPath, "devDependencies.json");

  if (fs.existsSync(dependenciesPath)) {
    dependencies = Object.assign(dependencies, require(dependenciesPath));
  }

  if (fs.existsSync(devDependenciesPath)) {
    devDependencies = Object.assign(devDependencies, require(devDependenciesPath));
  }

  walk(currentAddonPath).forEach(function (absoluteSrcPath) {
    var absoluteDestinationPath, relativeFilePath, relativeRenamedPath;
    relativeFilePath = path.relative(currentAddonPath, absoluteSrcPath);
    relativeRenamedPath = dotFilePath(relativeFilePath);
    absoluteDestinationPath = path.resolve(process.cwd(), relativeRenamedPath);

    if (templateExclusions.indexOf(relativeRenamedPath) >= 0) {
      return;
    }

    return copyAndReplace(absoluteSrcPath, absoluteDestinationPath, {});
  });
  templates.installDependencies(dependencies, yarnVersion, false);
  return templates.installDependencies(devDependencies, yarnVersion, true);
};

module.exports = {
  name: "extends",
  description: "setup additional feature to current project",
  func: run,
  examples: [{
    desc: "install eslint (AirBnB) and dependencies",
    cmd: "ruui extends --addon eslint"
  }],
  options: [{
    command: "--addon [string]",
    description: "feature to extends e.g 'eslint'"
  }]
};
//# sourceMappingURL=extends.js.map