"use strict";

var chalk, darwinTerminalTheme, defaultTerminalTheme, dotFilePath, fs, getJson, getTerminalTheme, handlePortAvailable, handlePortTaken, isDirectory, isPortTaken, path, rnCliModule, setEnv, uuid, writeFile;
fs = require("fs");
path = require("path");
({
  chalk
} = require("../util/modules"));
defaultTerminalTheme = {
  prefix: chalk.gray('['),
  suffix: chalk.gray(']'),
  progressbar: {
    prefix: '[',
    suffix: ']',
    complete: '#',
    remaining: '-'
  }
};
darwinTerminalTheme = {
  prefix: chalk.gray('｢'),
  suffix: chalk.gray('｣'),
  progressbar: {
    prefix: '⸨',
    suffix: '⸩',
    complete: '#',
    remaining: '-'
  }
};

getJson = function (path, fallback = {}) {
  if (fs.existsSync(path)) {
    return require(path);
  } else {
    return fallback;
  }
};

writeFile = function (file, data, callback) {
  var dirname;
  dirname = path.dirname(file);

  if (!fs.existsSync(dirname)) {
    fs.mkdirSync(dirname, {
      recursive: true
    });
  }

  fs.writeFileSync(file, data);

  if (callback) {
    return callback();
  }
};

getTerminalTheme = function () {
  switch (process.platform) {
    case "darwin":
      return darwinTerminalTheme;

    default:
      return defaultTerminalTheme;
  }
};

isPortTaken = function (options) {
  return new Promise(function (resolve, reject) {
    var server;
    return server = require("net").createServer().once("listening", function () {
      return handlePortAvailable(server, resolve);
    }).once("error", function (error) {
      return handlePortTaken(error, resolve, reject);
    }).listen(options);
  });
};

handlePortAvailable = function (server, resolve) {
  return server.once("close", function () {
    return resolve(false);
  }).close();
};

handlePortTaken = function (error, resolve, reject) {
  if (!(error.code === "EADDRINUSE")) {
    reject(error);
  }

  return resolve(true);
};

dotFilePath = function (filePath) {
  if (!filePath) {
    return filePath;
  }

  return filePath.replace("_eslintrc", ".eslintrc").replace("_gitignore", ".gitignore").replace("_gitattributes", ".gitattributes").replace("_babelrc", ".babelrc").replace("_flowconfig", ".flowconfig").replace("_buckconfig", ".buckconfig").replace("_watchmanconfig", ".watchmanconfig");
};

isDirectory = function (source) {
  return fs.lstatSync(source).isDirectory();
};

setEnv = function (opts) {
  return Object.keys(opts).forEach(function (key) {
    return process.env[key] = opts[key];
  });
};

uuid = function () {
  return "xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx".replace(/[xy]/g, function (c) {
    var r, v;
    r = Math.random() * 16 | 0;
    v = c === "x" ? r : r & 0x3 | 0x8;
    return v.toString(16);
  });
};

rnCliModule = function (...ext) {
  // find react-native's cli from different places
  if (fs.existsSync(path.resolve(process.cwd(), "node_modules", "@react-native-community"))) {
    return path.resolve(process.cwd(), "node_modules", "@react-native-community", "cli", "build", ...ext); // <- use legacy cli instead
  } else {
    return path.resolve(process.cwd(), "node_modules", "react-native", "local-cli", ...ext);
  }
};

module.exports = {
  terminalTheme: getTerminalTheme(),
  localModule: function (...ext) {
    return path.resolve(process.cwd(), ...ext);
  },
  ruuiModule: function (...ext) {
    return path.resolve(process.cwd(), "node_modules", "react-universal-ui", ...ext);
  },
  electronModule: function (...ext) {
    return path.resolve(process.cwd(), "node_modules", "electron", ...ext);
  },
  ruuiCliModule: function (...ext) {
    return path.resolve(process.cwd(), "node_modules", "react-universal-ui", "js", "cli", "local", ...ext);
  },
  rnCliModule: function (...ext) {
    return path.resolve(process.cwd(), "node_modules", "@react-native-community", "cli", "build", ...ext);
  },
  isDirectory: isDirectory,
  getDirectories: function (source) {
    return fs.readdirSync(source).map(function (name) {
      return path.join(source, name);
    }).filter(isDirectory);
  },
  templateExclusions: ["dependencies.json", "devDependencies.json"],
  isPortTaken,
  dotFilePath,
  writeFile,
  getJson,
  setEnv,
  uuid
};
//# sourceMappingURL=helper.js.map