"use strict";

var _fs = _interopRequireDefault(require("fs"));

var _path = _interopRequireDefault(require("path"));

var _helper = require("./helper");

var _configs = _interopRequireDefault(require("./configs"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var defaultPageExtractor, hydrate, pageMarkups, universalRender;

pageMarkups = function (AppRegistry, reactDom, initialProps) {
  var element, getStyleElement;
  ({
    element,
    getStyleElement
  } = AppRegistry.getApplication(_configs.default.appJson.name, {
    initialProps,
    rootTag: "root"
  }));
  return {
    initialHtml: reactDom.renderToString(element),
    initialStyles: reactDom.renderToStaticMarkup(getStyleElement())
  };
};

universalRender = function (AppRegistry, reactDom) {
  return function (req, res, next) {
    var env, initialMarkups, initialProps, isProduction, pageTemplate, publicPath;
    env = _configs.default.ruui.env();
    publicPath = _configs.default.ruui.publicPath(env);
    isProduction = env === "production";
    initialProps = {
      ssrLocation: req.baseUrl,
      ssrContext: {}
    };
    initialMarkups = pageMarkups(AppRegistry, reactDom, initialProps);
    pageTemplate = _configs.default.paths.getEjsTemplate();
    return res.render(pageTemplate, {
      ssrContext: Object.assign(initialMarkups, {
        serverSide: true,
        appName: _configs.default.appJson.displayName || _configs.default.appJson.name,
        publicPath: publicPath,
        buildId: _configs.default.ruuiJson.buildId,
        isProduction
      }, _configs.default.ruui.ejsTemplate)
    });
  };
};

defaultPageExtractor = function (routeConfig) {
  var ref;
  return ((ref = routeConfig[0]) != null ? ref.routes : void 0) || [];
};

hydrate = function (AppRegistry, reactDom, routeConfig, pageExtractor = defaultPageExtractor) {
  var ejs, env, fileName, finalMarkups, generateMarkup, i, initialMarkups, isProduction, len, options, page, pageLocation, pageTemplate, pages, publicPath, results, templatePath;
  env = _configs.default.ruui.env();
  publicPath = _configs.default.ruui.publicPath(env);
  ejs = require((0, _helper.localModule)("node_modules", "ejs"));
  isProduction = env === "production";
  pages = pageExtractor(routeConfig);
  templatePath = _configs.default.paths.getEjsTemplate();

  if (!_fs.default.existsSync) {
    console.log("can not find page template at ".concat(templatePath));
    return;
  }

  pageTemplate = _fs.default.readFileSync(templatePath, "utf-8");
  generateMarkup = ejs.compile(pageTemplate, {});
  results = [];

  for (i = 0, len = pages.length; i < len; i++) {
    page = pages[i];
    pageLocation = page.path || "/404";
    initialMarkups = pageMarkups(AppRegistry, reactDom, {
      ssrLocation: pageLocation,
      ssrContext: {}
    });
    options = {
      ssrContext: Object.assign(initialMarkups, {
        serverSide: true,
        appName: _configs.default.appJson.displayName || _configs.default.appJson.name,
        publicPath: publicPath,
        buildId: _configs.default.ruuiJson.buildId,
        isProduction
      }, _configs.default.ruui.ejsTemplate)
    };
    finalMarkups = generateMarkup(options);
    fileName = "".concat(pageLocation.replace('/', ''), ".html");

    if (page.path === "/") {
      fileName = "index.html";
    }

    results.push((0, _helper.writeFile)(_path.default.resolve(_configs.default.paths.ruui, fileName), finalMarkups));
  }

  return results;
};

module.exports = {
  universalRender,
  pageMarkups,
  hydrate
};
//# sourceMappingURL=ssr.js.map