"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireWildcard(require("react"));

var _reactNative = require("react-native");

var _reactNativeSvg = require("react-native-svg");

var _utils = require("../utils");

var appActions = _interopRequireWildcard(require("../utils/store/appAction"));

var _typeDefinition = require("../typeDefinition");

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

class RuuiDropdown extends _react.Component {
  constructor(props) {
    super(props);

    _defineProperty(this, "props", void 0);

    _defineProperty(this, "playAnimation", () => {
      this.enterAnimation.setValue(0);

      _reactNative.Animated.timing(this.enterAnimation, {
        toValue: 1,
        duration: 800,
        easing: _reactNative.Easing.in(_reactNative.Easing.bezier(0.23, 1, 0.32, 1)),
        useNativeDriver: false
      }).start();
    });

    _defineProperty(this, "closeModal", () => {
      const {
        dispatch,
        configs
      } = this.props;
      dispatch(appActions.toggleDropdown(false, configs));
    });

    _defineProperty(this, "onLayout", ({
      nativeEvent
    }) => {
      this.setState({
        layout: nativeEvent.layout
      });
    });

    this.enterAnimation = new _reactNative.Animated.Value(0);
    this.state = {
      layout: {}
    };
  }

  componentDidMount() {
    this.playAnimation();
  }

  componentWillUnmount() {
    const {
      configs: {
        onClose
      }
    } = this.props;
    if (onClose) onClose();
  }

  componentDidUpdate(prevProps) {
    const {
      active
    } = this.props;

    if (prevProps.active !== active && active) {
      this.playAnimation();
    }
  }

  render() {
    const {
      active,
      configs
    } = this.props;
    return active ? /*#__PURE__*/_react.default.createElement(_reactNative.View, {
      style: styles.container
    }, configs.tapToClose ? /*#__PURE__*/_react.default.createElement(_reactNative.TouchableWithoutFeedback, {
      onPress: this.closeModal
    }, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
      style: styles.touchableMask
    })) : /*#__PURE__*/_react.default.createElement(_reactNative.View, null), this.renderDropDown()) : /*#__PURE__*/_react.default.createElement(_reactNative.View, null);
  }

  renderDropDown() {
    const {
      configs,
      screenSize
    } = this.props;
    const {
      layout
    } = this.state;
    const context = configs.context || {};
    const positionOffset = configs.offset || {
      top: 0,
      left: 0
    };
    const arrowOffset = configs.arrowOffset || {
      top: 0,
      left: 0
    };
    const containerLayout = configs.containerLayout || {
      x: 0,
      y: 0,
      width: 0,
      height: 0
    };
    const InnerComponent = configs.component || configs.Component || EmptyDropdown;
    const arrowSize = configs.arrowSize || 8;
    const flattenWrapperStyle = _reactNative.StyleSheet.flatten(configs.wrapperStyle) || {};
    const backgroundColor = flattenWrapperStyle.backgroundColor || '#ffffff';
    const finalBorderRadius = flattenWrapperStyle.borderRadius || 3;
    const animatedDirection = configs.animatedDirection || configs.direction;
    const animatedConfigs = (0, _utils.directionAnimatedConfigs)(animatedDirection, 10, this.enterAnimation, finalBorderRadius);
    const snappingPosition = (0, _utils.directionSnap)(containerLayout.y, containerLayout.x, containerLayout.width, containerLayout.height, layout.width, layout.height, configs.direction, configs.spacing, screenSize);
    const arrowPosition = (0, _utils.arrowSnap)(layout.width, layout.height, arrowSize, configs.direction);
    const wrapperStyles = {
      position: 'absolute',
      top: snappingPosition.top + positionOffset.top,
      left: snappingPosition.left + positionOffset.left,
      opacity: layout.width ? 1 : 0
    };
    const containerStyles = {
      transform: animatedConfigs.transform,
      opacity: animatedConfigs.opacity,
      ...animatedConfigs.borderRadius
    };
    const arrowStyle = {
      position: 'absolute',
      top: arrowPosition.top + arrowOffset.top,
      left: arrowPosition.left + arrowOffset.left,
      transform: arrowPosition.transform || [],
      width: arrowSize + 2,
      height: arrowSize * 2
    };
    return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
      style: [wrapperStyles, {
        zIndex: configs.zIndex
      }],
      onLayout: this.onLayout
    }, /*#__PURE__*/_react.default.createElement(_reactNative.Animated.View, {
      style: [styles.dropdownContainer, configs.wrapperStyle, containerStyles]
    }, /*#__PURE__*/_react.default.createElement(InnerComponent, {
      configs: configs,
      animation: this.enterAnimation,
      context: context,
      close: this.closeModal
    }), configs.showArrow !== false && /*#__PURE__*/_react.default.createElement(_reactNativeSvg.Svg, {
      style: arrowStyle
    }, /*#__PURE__*/_react.default.createElement(_reactNativeSvg.Path, {
      d: drawArrow(arrowSize),
      transform: "translate(2,0)",
      fill: backgroundColor
    }))));
  }

}

var _default = (0, _utils.connect)(() => {
  return {};
})(RuuiDropdown);

exports.default = _default;

function EmptyDropdown(props) {
  return /*#__PURE__*/_react.default.createElement(_reactNative.View, null, /*#__PURE__*/_react.default.createElement(_reactNative.Text, null, "Default dropdown"));
}

const drawArrow = size => {
  const width = size;
  const height = size * 2;
  const baseSize = width / 2.8;
  const topCurve = "Q0 ".concat(baseSize / 2, ", ").concat(baseSize, " ").concat(baseSize);
  const topEdge = "Q".concat(width, " ").concat(height / 2 - baseSize, ", ").concat(width, " ").concat(height / 2);
  const bottomEdge = "Q".concat(width, " ").concat(height / 2 + baseSize, ", ").concat(baseSize, " ").concat(height - baseSize);
  const bottomCurve = "Q".concat(0, " ", height - baseSize / 2, ", 0 ").concat(height);
  return "M-2,0 L0,0 ".concat(topCurve, " ").concat(topEdge, " ").concat(bottomEdge, " ").concat(bottomCurve, " L-2,").concat(height, " Z");
};

const styles = _reactNative.StyleSheet.create({
  container: {
    zIndex: 1000,
    position: 'absolute',
    top: 0,
    bottom: 0,
    left: 0,
    right: 0
  },
  touchableMask: {
    position: 'absolute',
    top: 0,
    bottom: 0,
    left: 0,
    right: 0
  },
  dropdownContainer: {
    backgroundColor: '#ffffff',
    borderRadius: 3
  }
});
//# sourceMappingURL=dropdown.js.map