"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.defaultMaskPropsGenerator = defaultMaskPropsGenerator;
exports.default = void 0;

var _react = _interopRequireWildcard(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _reactNative = require("react-native");

var _selector = _interopRequireDefault(require("./selector"));

var _loadingMask = _interopRequireDefault(require("./loadingMask"));

var _closeableModal = _interopRequireDefault(require("./closeableModal"));

var _utils = require("../utils");

var appActions = _interopRequireWildcard(require("../utils/store/appAction"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

class RuuiModal extends _react.Component {
  constructor(props) {
    super(props);

    _defineProperty(this, "playAnimation", (toValue, callback) => {
      if (this.animation) this.animation.clear();
      const easing = toValue === 0 ? _reactNative.Easing.out(_reactNative.Easing.bezier(0, 0, 0.58, 1)) : _reactNative.Easing.in(_reactNative.Easing.bezier(0, 0.48, 0.35, 1)),
            animations = [_reactNative.Animated.timing(this.enterAnimation, {
        toValue,
        duration: 500,
        easing,
        useNativeDriver: false
      })];
      this.animation = _reactNative.Animated.parallel(animations).start(callback);
    });

    this.state = {
      active: props.active
    };
    this.enterAnimation = new _reactNative.Animated.Value(0);
  }

  componentDidMount() {
    const {
      active,
      animationDelay
    } = this.props;
    setTimeout(() => this.playTransition(active), animationDelay);
  }

  componentDidUpdate(prevProps) {
    const {
      active
    } = this.props;

    if (prevProps.active !== active) {
      this.playTransition(active);
    }
  }

  playTransition(active) {
    const {
      configs = {}
    } = this.props;
    const nextValue = active ? 1 : 0;

    if (!active) {
      if (configs.instantClose) {
        this.setState({
          active: null
        });
        if (configs.onClose) configs.onClose();
      } else {
        this.playAnimation(nextValue, () => {
          this.setState({
            active: null
          });
          if (configs.onClose) configs.onClose();
        });
      }
    } else {
      this.setState({
        active
      });
      this.playAnimation(nextValue);
    }
  }

  render() {
    const {
      configs = {},
      modalCount,
      type: modalType
    } = this.props,
          {
      active
    } = this.state,
          globalConfigs = (0, _utils.valueAt)(this, 'context.ruuiConfigs.modal'),
          containerPropsGenerator = configs.maskProps || globalConfigs.maskProps,
          containerProps = containerPropsGenerator(this.enterAnimation, configs, modalCount, modalType);

    if (configs.maskProps && !containerProps.style) {
      containerProps.style = globalConfigs.maskProps(this.enterAnimation, configs, modalCount, modalType).style;
    }

    return active ? /*#__PURE__*/_react.default.createElement(_reactNative.Animated.View, containerProps, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
      style: styles.innerTouchable
    }, this.renderModalInner())) : /*#__PURE__*/_react.default.createElement(_reactNative.View, null);
  }

  renderModalInner() {
    const {
      dispatch,
      type: modalType,
      active,
      configs: modalConfigs
    } = this.props;

    switch (modalType) {
      case 'select':
        return /*#__PURE__*/_react.default.createElement(_selector.default, {
          onRequestClose: configs => dispatch(appActions.toggleSelector(false, configs)),
          animation: this.enterAnimation,
          active: active,
          configs: modalConfigs
        });

      case 'modal':
        return /*#__PURE__*/_react.default.createElement(_closeableModal.default, {
          onRequestClose: configs => dispatch(appActions.toggleModal(false, configs)),
          animation: this.enterAnimation,
          active: active,
          configs: modalConfigs
        });

      case 'loading':
        return /*#__PURE__*/_react.default.createElement(_loadingMask.default, {
          animation: this.enterAnimation,
          active: active,
          configs: modalConfigs
        });

      default:
        return /*#__PURE__*/_react.default.createElement(_reactNative.View, null);
    }
  }

}

exports.default = RuuiModal;

_defineProperty(RuuiModal, "props", void 0);

_defineProperty(RuuiModal, "contextTypes", {
  ruuiConfigs: _propTypes.default.object
});

function defaultMaskPropsGenerator(animation, configs, modalCount, modalType) {
  const averageOpacity = 0.8 / modalCount + modalCount * 0.1,
        backgroundColor = animation.interpolate({
    inputRange: [0, 1],
    outputRange: ['rgba(0, 0, 0, 0)', "rgba(0, 0, 0, ".concat(averageOpacity, ")")]
  }),
        style = [styles.container, {
    zIndex: configs.zIndex,
    backgroundColor
  }];
  return {
    style
  };
}

const styles = _reactNative.StyleSheet.create({
  container: {
    position: 'absolute',
    top: 0,
    left: 0,
    right: 0,
    bottom: 0
  },
  innerTouchable: {
    flex: 1
  },
  touchableMask: {
    position: 'absolute',
    top: 0,
    right: 0,
    left: 0,
    bottom: 0
  }
});
//# sourceMappingURL=modal.js.map