"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireWildcard(require("react"));

var _reactNative = require("react-native");

var _propTypes = _interopRequireDefault(require("prop-types"));

var _lodash = require("lodash");

var _core = _interopRequireDefault(require("../configs/core"));

var _utils = require("../utils");

var _ruuiStore = require("../utils/ruuiStore");

var _appReducer = _interopRequireDefault(require("../store/appReducer"));

var appActions = _interopRequireWildcard(require("../store/action/app"));

var _typeDefinition = require("../typeDefinition");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

const navigator = global.navigator || {},
      connectionModule = navigator.connection || navigator.mozConnection || navigator.webkitConnection;

class RuuiProvider extends _react.Component {
  constructor(props) {
    super(props);

    _defineProperty(this, "subscribeAndUpdateDimensions", () => {
      this.handleDimensionChange({
        window: _reactNative.Dimensions.get('window'),
        screen: _reactNative.Dimensions.get('screen')
      });

      _reactNative.Dimensions.addEventListener('change', this.handleDimensionChange);
    });

    _defineProperty(this, "handleDimensionChange", data => {
      this.store.dispatch(appActions.updateDimensionsInfo(data));
    });

    _defineProperty(this, "subscribeAndUpdateNetworkInfo", () => {
      _reactNative.NetInfo.getConnectionInfo && _reactNative.NetInfo.getConnectionInfo().then(connectionInfo => this.handleConnectionTypeChange(connectionInfo));
      _reactNative.NetInfo.isConnected.getConnectionInfo && _reactNative.NetInfo.isConnected.getConnectionInfo().then(isConnected => this.handleIsConnectedChange(isConnected));

      _reactNative.NetInfo.addEventListener('connectionChange', this.handleConnectionTypeChange);

      _reactNative.NetInfo.isConnected.addEventListener('connectionChange', this.handleIsConnectedChange);
    });

    _defineProperty(this, "handleConnectionTypeChange", connectionType => {
      this.store.dispatch(appActions.updateNetInfo({
        connectionType
      }));
    });

    _defineProperty(this, "handleIsConnectedChange", isConnected => {
      this.store.dispatch(appActions.updateNetInfo({
        isConnected
      }));
    });

    this.store = props.store;
    this.configs = (0, _lodash.merge)({}, _core.default, props.configs);
  }

  getChildContext() {
    return {
      ruuiStore: this.store,
      ruuiConfigs: this.configs
    };
  }

  componentDidMount() {
    const {
      store,
      subscribeDimension,
      subscribeNetInfo
    } = this.props;
    if (_utils.isServer || !store) return;
    if (subscribeDimension) this.subscribeAndUpdateDimensions();
    if (subscribeNetInfo && connectionModule) this.subscribeAndUpdateNetworkInfo();
  }

  componentWillUnmount() {
    const {
      store,
      subscribeDimension,
      subscribeNetInfo
    } = this.props;
    if (_utils.isServer || !store) return;

    if (subscribeDimension) {
      _reactNative.Dimensions.removeEventListener('change', this.handleDimensionChange);
    }

    if (subscribeNetInfo && connectionModule) {
      _reactNative.NetInfo.removeEventListener('connectionChange', this.handleConnectionTypeChange);

      _reactNative.NetInfo.isConnected.removeEventListener('connectionChange', this.handleIsConnectedChange);
    }
  }

  render() {
    const {
      children
    } = this.props;
    return children;
  }

}

_defineProperty(RuuiProvider, "props", void 0);

_defineProperty(RuuiProvider, "defaultProps", {
  configs: {},
  subscribeNetInfo: false,
  subscribeDimension: true,
  store: (0, _ruuiStore.createStore)(_appReducer.default)
});

_defineProperty(RuuiProvider, "childContextTypes", {
  ruuiStore: _propTypes.default.object,
  ruuiConfigs: _propTypes.default.object
});

var _default = RuuiProvider;
exports.default = _default;
//# sourceMappingURL=ruuiProvider.js.map