"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireWildcard(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _reactNative = require("react-native");

var _responsibleTouchArea = _interopRequireDefault(require("./responsibleTouchArea"));

var _selectorItem = _interopRequireDefault(require("./selectorItem"));

var _utils = require("../utils");

var _screen = require("../utils/screen");

var appActions = _interopRequireWildcard(require("../utils/store/appAction"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

class Selector extends _react.Component {
  constructor(props, context) {
    super(props);

    _defineProperty(this, "onItemPick", item => {
      const {
        configs
      } = this.props;
      this.store.dispatch(appActions.toggleSelector(false));
      if (configs.onSelect) configs.onSelect(item);

      if (configs.onChange && JSON.stringify(configs.value) !== JSON.stringify(item)) {
        configs.onChange(item);
      }
    });

    _defineProperty(this, "cancelSelector", () => {
      const {
        configs
      } = this.props;
      this.store.dispatch(appActions.toggleSelector(false, {
        id: configs.id
      }));
      if (configs.onCancel) configs.onCancel();
    });

    this.store = context.ruuiStore;
  }

  render() {
    const {
      animation,
      configs,
      active,
      onRequestClose
    } = this.props,
          translateY = animation.interpolate({
      inputRange: [0, 0.32, 1],
      outputRange: [maxContainerSize, maxContainerSize * 0.15, 0]
    }),
          selectionContainerStyles = {
      transform: [{
        translateY
      }]
    },
          OptionWrapperElement = configs.options.length > 5 ? _reactNative.ScrollView : _reactNative.View,
          pointerEvents = active ? 'auto' : 'none';
    return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
      pointerEvents: pointerEvents,
      style: styles.container
    }, configs.tapToClose ? /*#__PURE__*/_react.default.createElement(_reactNative.TouchableWithoutFeedback, {
      onPress: () => onRequestClose(configs)
    }, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
      style: styles.touchableMask
    })) : /*#__PURE__*/_react.default.createElement(_reactNative.View, null), /*#__PURE__*/_react.default.createElement(_reactNative.Animated.View, {
      style: [styles.selectionContainer, selectionContainerStyles]
    }, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
      style: styles.optionWrapper
    }, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
      style: styles.selectTitle
    }, /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
      style: styles.selectTitleText
    }, configs.selectText)), /*#__PURE__*/_react.default.createElement(_reactNative.View, {
      style: {
        maxHeight: 255
      }
    }, /*#__PURE__*/_react.default.createElement(OptionWrapperElement, {
      style: {
        backgroundColor: '#f9f9f9'
      }
    }, this.renderOptions()), !_utils.isAndroid && /*#__PURE__*/_react.default.createElement(_reactNative.View, {
      style: styles.optionTails
    }))), /*#__PURE__*/_react.default.createElement(_reactNative.View, {
      style: styles.commandWrapper
    }, this.renderCommands())));
  }

  renderOptions() {
    const {
      configs
    } = this.props,
          {
      options = []
    } = configs;
    return options.map((item, i) => {
      return /*#__PURE__*/_react.default.createElement(_selectorItem.default, {
        key: i,
        optionInstance: item,
        activeInstance: configs.value,
        getTitle: configs.getTitle,
        onPress: this.onItemPick
      });
    });
  }

  renderCommands() {
    const {
      configs
    } = this.props;
    return /*#__PURE__*/_react.default.createElement(_responsibleTouchArea.default, {
      onPress: this.cancelSelector,
      rippleColor: _utils.colors.iOsBlue,
      wrapperStyle: [styles.commandItemWrapper],
      innerStyle: styles.optionItemInner,
      fadeLevel: 0.04
    }, /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
      style: styles.commandTitle
    }, configs.cancelText));
  }

}

_defineProperty(Selector, "props", void 0);

_defineProperty(Selector, "contextTypes", {
  ruuiStore: _propTypes.default.object
});

var _default = Selector;
exports.default = _default;
const maxContainerSize = 500,
      selectorRadius = _utils.isAndroid ? 3 : 8,
      borderWidth = _utils.isAndroid ? 0 : 1,
      selectorMargin = 20,
      selectorPadding = _utils.isAndroid ? 20 : 8,
      selectionAlign = _utils.isAndroid ? 'left' : 'center';

const styles = _reactNative.StyleSheet.create({
  container: {
    flex: 1
  },
  selectionContainer: {
    position: 'absolute',
    bottom: 0,
    left: 0,
    right: 0,
    maxHeight: maxContainerSize,
    alignItems: 'center'
  },
  touchableMask: {
    position: 'absolute',
    top: 0,
    right: 0,
    left: 0,
    bottom: 0
  },
  selectTitle: {
    flex: 1,
    backgroundColor: '#f9f9f9',
    borderTopLeftRadius: selectorRadius,
    borderTopRightRadius: selectorRadius,
    borderBottomWidth: borderWidth,
    borderColor: '#dedede'
  },
  selectTitleText: {
    padding: selectorPadding,
    paddingTop: 9,
    paddingBottom: 9,
    textAlign: selectionAlign,
    color: '#8f8f8f',
    backgroundColor: 'transparent',
    fontSize: 14,
    fontWeight: '300'
  },
  optionWrapper: {
    margin: selectorMargin,
    marginBottom: _utils.isAndroid ? 0 : selectorMargin / 2,
    width: (0, _screen.screenWidthPadding)(selectorMargin, 400)
  },
  optionItemInner: {
    padding: selectorPadding,
    paddingTop: 12,
    paddingBottom: 12
  },
  optionTails: {
    height: selectorRadius,
    backgroundColor: '#f9f9f9',
    borderBottomLeftRadius: selectorRadius,
    borderBottomRightRadius: selectorRadius
  },
  commandWrapper: {
    margin: selectorMargin,
    marginTop: 0,
    borderRadius: selectorRadius,
    borderTopLeftRadius: _utils.isAndroid ? 0 : selectorRadius,
    borderTopRightRadius: _utils.isAndroid ? 0 : selectorRadius,
    backgroundColor: _utils.isAndroid ? '#f9f9f9' : 'transparent',
    overflow: 'hidden',
    width: (0, _screen.screenWidthPadding)(selectorMargin, 400)
  },
  commandItemWrapper: {
    flex: 1,
    backgroundColor: '#f5f5f5',
    borderBottomWidth: borderWidth,
    borderColor: '#dedede',
    borderRadius: selectorRadius
  },
  commandTitle: {
    color: _utils.colors.iOsBlue,
    fontSize: 17,
    textAlign: _utils.isAndroid ? 'center' : 'center',
    backgroundColor: 'transparent'
  }
});
//# sourceMappingURL=selector.js.map