"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireWildcard(require("react"));

var _reactNative = require("react-native");

var _typeDefinition = require("../typeDefinition");

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

class Snackbar extends _react.Component {
  constructor(props) {
    super(props);

    _defineProperty(this, "props", void 0);

    const initialPosition = props.aliveIndex - 1;
    this.positionAnimation = new _reactNative.Animated.Value(initialPosition);
    this.firstItemAnimation = new _reactNative.Animated.Value(0);
  }

  componentDidUpdate(prevProps) {
    const {
      aliveIndex
    } = this.props;

    if (prevProps.aliveIndex !== aliveIndex) {
      _reactNative.Animated.timing(this.positionAnimation, {
        toValue: aliveIndex,
        duration: 1000,
        easing: _reactNative.Easing.in(_reactNative.Easing.bezier(0.23, 1, 0.32, 1))
      }).start();

      if (prevProps.aliveIndex === 0 && aliveIndex !== -1) {
        _reactNative.Animated.timing(this.firstItemAnimation, {
          toValue: aliveIndex === 0 ? 0 : 1,
          duration: 1000,
          easing: _reactNative.Easing.in(_reactNative.Easing.bezier(0.23, 1, 0.32, 1)),
          useNativeDriver: false
        }).start();
      }
    }
  }

  componentDidMount() {
    const {
      configs,
      aliveIndex,
      onStartTimeout,
      onTimeout
    } = this.props;

    _reactNative.Animated.timing(this.positionAnimation, {
      toValue: aliveIndex,
      duration: 1000,
      easing: _reactNative.Easing.in(_reactNative.Easing.bezier(0.23, 1, 0.32, 1)),
      useNativeDriver: true
    }).start(() => {
      this.timeout = setTimeout(() => {
        onStartTimeout(configs);

        _reactNative.Animated.timing(this.positionAnimation, {
          toValue: aliveIndex,
          duration: 1000,
          easing: _reactNative.Easing.in(_reactNative.Easing.bezier(0.23, 1, 0.32, 1)),
          useNativeDriver: true
        }).start(() => onTimeout(configs));
      }, configs.timeout || 5000);
    });
  }

  render() {
    const {
      configs,
      edge,
      edgeOffset,
      itemHeight,
      index
    } = this.props,
          contentRenderer = configs.contentRenderer || defaultContentRenderer,
          velocity = edge === 'top' ? itemHeight : -itemHeight,
          borderRadius = this.firstItemAnimation.interpolate({
      inputRange: [0, 1],
      outputRange: [0, 3]
    }),
          marginHorizontal = this.firstItemAnimation.interpolate({
      inputRange: [0, 1],
      outputRange: [0, 12]
    }),
          offset = this.positionAnimation.interpolate({
      inputRange: [0, 100],
      outputRange: [0, 100 * velocity]
    }),
          containerStyles = {
      zIndex: -index + 100,
      borderRadius,
      marginHorizontal,
      transform: [{
        translateY: offset
      }]
    };

    if (edge === 'top') {
      containerStyles.top = edgeOffset;
    } else {
      containerStyles.bottom = edgeOffset;
    }

    return /*#__PURE__*/_react.default.createElement(_reactNative.Animated.View, {
      style: [styles.container, configs.containerStyle, containerStyles]
    }, contentRenderer(configs));
  }

}

var _default = Snackbar;
exports.default = _default;

function defaultContentRenderer(configs) {
  return /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    numberOfLines: 1,
    style: styles.message
  }, configs.message);
}

const styles = _reactNative.StyleSheet.create({
  container: {
    padding: 14,
    marginTop: 6,
    backgroundColor: '#454545',
    position: 'absolute',
    left: 0,
    right: 0
  },
  message: {
    color: '#ffffff'
  }
});
//# sourceMappingURL=snackbar.js.map