"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.collectionMutate = collectionMutate;
exports.collectionInsert = collectionInsert;
exports.collectionDestroy = collectionDestroy;
exports.firstKeyOf = firstKeyOf;

function collectionMutate(collection, instance, uniqueKey = 'id', merge = true, additionalMerge = {}) {
  if (!instance || !instance[uniqueKey]) {
    console.warn("Immutable collection MUTATE require [".concat(uniqueKey, "] field of the new instance... return original collection."), instance);
    return collection;
  }

  const itemIndex = collection.findIndex(item => item[uniqueKey] === instance[uniqueKey]);
  if (itemIndex < 0) return collection;
  const liveItem = merge ? { ...collection[itemIndex],
    ...instance,
    ...additionalMerge
  } : instance,
        headItems = collection.slice(0, itemIndex),
        tailItems = collection.slice(itemIndex + 1);
  return [...headItems, liveItem, ...tailItems];
}

function collectionInsert(collection, instance, pop = true) {
  return pop ? [instance, ...collection] : [...collection, instance];
}

function collectionDestroy(collection, instance, uniqueKey = 'id') {
  if (!instance || !instance[uniqueKey]) {
    console.warn("Immutable collection DESTROY require [".concat(uniqueKey, "] field of the new instance... return original collection."), instance);
    return collection;
  }

  const itemIndex = collection.findIndex(item => item[uniqueKey] === instance[uniqueKey]);
  if (itemIndex < 0) return collection;
  const headItems = collection.slice(0, itemIndex),
        tailItems = collection.slice(itemIndex + 1);
  return [...headItems, ...tailItems];
}

function firstKeyOf(instance, address) {
  const result = instance[Object.keys(instance)[0]];

  if (address && result[address]) {
    return result[address];
  } else {
    return result;
  }
}
//# sourceMappingURL=collection.js.map