"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createStore = createStore;
exports.combineReducers = combineReducers;
exports.connect = connect;

var _react = _interopRequireWildcard(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _helpers = require("./helpers");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function createStore(reducer) {
  let state,
      listeners = [];

  const getState = () => state;

  const getListeners = () => listeners;

  const dispatch = action => {
    state = reducer(state, action);
    listeners.forEach(listener => listener(state));
  };

  const subscribe = listener => {
    listeners.push(listener);
    return () => {
      listeners = listeners.filter(l => l !== listener);
    };
  };

  dispatch({});
  return {
    getState,
    dispatch,
    subscribe,
    getListeners
  };
}

function combineReducers(reducers) {
  const reducerKeys = Object.keys(reducers);
  return (state = {}, action) => {
    let hasChanged = false;
    const nextState = {};

    for (let i = 0; i < reducerKeys.length; i += 1) {
      const key = reducerKeys[i],
            reducer = reducers[key],
            previousStateForKey = state[key],
            nextStateForKey = reducer(previousStateForKey, action);
      nextState[key] = nextStateForKey;
      hasChanged = hasChanged || nextStateForKey !== previousStateForKey;
    }

    return hasChanged ? nextState : state;
  };
}

function connect(stateToPropsFactory) {
  return function (BaseComponent) {
    var _class, _temp;

    const currentDisplayName = BaseComponent.displayName || BaseComponent.name,
          enhancedDisplayName = "RuuiConnect(".concat(currentDisplayName, ")");
    return _temp = _class = class RuuiConnected extends _react.Component {
      constructor(props, context) {
        super(props);

        _defineProperty(this, "syncProps", () => {
          const {
            generatedProps
          } = this.state,
                nextProps = stateToPropsFactory(this.store.getState());

          if (!(0, _helpers.shallowEqual)(generatedProps, nextProps)) {
            this.setState({
              generatedProps: nextProps
            });
          }
        });

        this.store = context.ruuiStore;
        this.unSubscribe = this.store.subscribe(this.syncProps);
        this.state = {
          generatedProps: stateToPropsFactory(this.store.getState())
        };
      }

      componentWillUnmount() {
        this.unSubscribe();
      }

      render() {
        const {
          generatedProps
        } = this.state,
              {
          dispatch
        } = this.store;
        return /*#__PURE__*/_react.default.createElement(BaseComponent, _extends({}, this.props, generatedProps, {
          dispatch: dispatch
        }));
      }

    }, _defineProperty(_class, "displayName", enhancedDisplayName), _defineProperty(_class, "contextTypes", {
      ruuiStore: _propTypes.default.object
    }), _temp;
  };
}
//# sourceMappingURL=ruuiStore.js.map