"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.initialAppState = initialAppState;
exports.appReducer = appReducer;

var Actions = _interopRequireWildcard(require("./actions"));

var _collection = require("../collection");

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const defaultSelectorConfigs = {
  selectText: 'Select',
  cancelText: 'Cancel',
  options: [{
    title: 'Option 1'
  }, {
    title: 'Option 2'
  }]
};

function initialAppState(initialState = {}, previousState = {}) {
  return {
    activeModals: {
      defaultSelector: null,
      defaultModal: null,
      loading: null
    },
    activeDropdown: {
      active: false,
      configs: {
        tapToClose: true
      }
    },
    snackBars: [],
    themeConfigs: previousState.themeConfigs || {},
    netInfo: previousState.netInfo || {},
    dimensions: previousState.dimensions || {},
    ...initialState
  };
}

function appReducer(reducer) {
  const initialState = initialAppState(reducer(undefined, {
    type: Actions.ReduxInit
  }));
  return function (state = initialState, action) {
    switch (action.type) {
      case Actions.ToggleSelect:
        return handleToggleSelect(state, action);

      case Actions.ToggleModal:
        return handleToggleModal(state, action);

      case Actions.ToggleDropdown:
        return handleToggleDropdown(state, action);

      case Actions.ToggleLoading:
        return handleToggleLoading(state, action);

      case Actions.InsertSnackBar:
        return { ...state,
          snackBars: (0, _collection.collectionInsert)(state.snackBars, action.configs, true)
        };

      case Actions.StartDestroySnackBar:
        return { ...state,
          snackBars: (0, _collection.collectionMutate)(state.snackBars, {
            id: action.configs.id,
            destroying: true
          })
        };

      case Actions.DestroySnackBar:
        return { ...state,
          snackBars: (0, _collection.collectionDestroy)(state.snackBars, action.configs)
        };

      case Actions.UpdateThemeConfigs:
        return { ...state,
          themeConfigs: { ...state.themeConfigs,
            ...action.configs
          }
        };

      case Actions.UpdateDimensionInfo:
        return { ...state,
          dimensions: { ...state.dimensions,
            ...action.info
          }
        };

      case Actions.UpdateNetInfo:
        return { ...state,
          netInfo: { ...state.netInfo,
            ...action.info
          }
        };

      case Actions.ResetState:
        return initialAppState(reducer(undefined, {
          type: Actions.ReduxInit
        }), state);

      default:
        return reducer(state, action);
    }
  };
}

function handleToggleSelect(state, action) {
  const selectorName = action.configs.id || 'default',
        selectorConfigs = {
    type: 'select',
    active: action.flag === true,
    configs: action.flag === true ? { ...defaultSelectorConfigs,
      ...action.configs
    } : state.activeModals["".concat(selectorName, "Selector")].configs
  };
  return { ...state,
    activeModals: { ...state.activeModals,
      ["".concat(selectorName, "Selector")]: selectorConfigs
    }
  };
}

function handleToggleModal(state, action) {
  const modalName = action.configs.id || 'default',
        currentModal = state.activeModals[modalName] || {},
        modalConfigs = {
    type: 'modal',
    active: action.flag === true,
    configs: action.flag === true ? { ...action.configs
    } : currentModal.configs
  };
  return { ...state,
    activeModals: { ...state.activeModals,
      [modalName]: modalConfigs
    }
  };
}

function handleToggleLoading(state, action) {
  return { ...state,
    activeModals: { ...state.activeModals,
      loading: action.flag === true ? {
        type: 'loading',
        active: action.flag === true,
        configs: action.flag ? { ...action.configs
        } : {}
      } : null
    }
  };
}

function handleToggleDropdown(state, action) {
  return { ...state,
    activeDropdown: {
      active: action.flag === true,
      configs: action.flag === true ? { ...action.configs,
        tapToClose: action.configs.tapToClose || true
      } : state.activeDropdown.configs
    }
  };
}
//# sourceMappingURL=appReducer.js.map