var chalk, checkNodeVersion, childProcess, cli, commands, createAfterConfirmation, createProject, fs, getInstallPackage, getYarnVersionIfAvailable, init, innerLocalCliPath, installPackage, installedCliPath, modulePath, options, outerLocalCliPath, packageJsonPath, path, printVersionAndExit, prompt, run, ruuiInitUsage, ruuiInstruction, ruuiInvalidNodeVersion, ruuiInvalidProjectKeyword, ruuiInvalidProjectName, ruuiNoCommandMessage, ruuiUnrecognizedCommand, semver, validateProjectName;
fs = require("fs");
path = require("path");
childProcess = require("child_process");
chalk = require(path.resolve(process.cwd(), "node_modules", "chalk"));
prompt = require("prompt");
semver = require("semver");
options = require("minimist")(process.argv.slice(2));
ruuiInstruction = "Usage: ruui [command] [options]\n\nCommands:\n	init <ProjectName> [options]  generates a new project and installs its dependencies\n\nOptions:\n	-h, --help    output usage information\n	-v, --version use a specific version of React Universal UI\n	--template use an app template. Use --template to see available templates.\n";
ruuiNoCommandMessage = "You did not pass any commands, run `ruui --help` to see a list of all available commands.";
ruuiInitUsage = "Usage: react-native init <ProjectName> [--verbose]";

ruuiUnrecognizedCommand = function (command) {
  return "Command ".concat(command, " unrecognized. Make sure that you have run `npm install` and that you are inside RUUI project.");
};

ruuiInvalidProjectName = function (name) {
  return "".concat(name, " is not a valid name for a project. Please use a valid identifier name (alphanumeric).");
};

ruuiInvalidProjectKeyword = function (name) {
  return "".concat(name, " is not a valid name for a project. Please do not use the reserved word \"React\".");
};

ruuiInvalidNodeVersion = function (current, required) {
  return "You are currently running Node ".concat(current, " but React Native requires ").concat(required, ".\nPlease use a supported version of Node.\nSee https://facebook.github.io/react-native/docs/getting-started.html");
};

modulePath = function () {
  return path.resolve.apply(null, [process.cwd(), "node_modules"].concat(Object.values(arguments)));
};

packageJsonPath = function (module = "react-native") {
  return path.resolve(process.cwd(), "node_modules", module, "package.json");
};

printVersionAndExit = function (ruuiPackageJsonPath) {
  var err;
  console.log("ruui-cli: ".concat(require("./package.json").version));

  try {
    console.log("react-universal-ui: ".concat(require(ruuiPackageJsonPath).version));
  } catch (error1) {
    err = error1;
    console.log("react-universal-ui: n/a - not inside a React Universal UI project directory");
  }

  return process.exit();
};

if (options._.length === 0 && (options.v || options.version)) {
  printVersionAndExit(packageJsonPath("react-universal-ui"));
}

cli = null; // <- check if current project contain it's own cli then use it, otherwise try to load cli from react-universal-ui

innerLocalCliPath = path.resolve(process.cwd(), "cli.js"); // <- local-cli of production run

outerLocalCliPath = path.resolve(process.cwd(), "../../cli.js"); // <- local-cli of development run

installedCliPath = modulePath("react-universal-ui", "cli.js"); // <- default local-cli of ruui

if (fs.existsSync(innerLocalCliPath)) {
  cli = require(innerLocalCliPath);
} else if (fs.existsSync(outerLocalCliPath)) {
  cli = require(outerLocalCliPath);
} else if (fs.existsSync(installedCliPath)) {
  cli = require(installedCliPath);
}

commands = options._;

getYarnVersionIfAvailable = function () {
  var err, versionCommand, yarnVersion;
  yarnVersion = null;
  versionCommand = process.platform.startsWith("win") ? "yarn --version 2> NUL" : "yarn --version 2>/dev/null";

  try {
    yarnVersion = (childProcess.execSync(versionCommand).toString() || "").trim();
  } catch (error1) {
    err = error1;
    return null;
  }

  try {
    if (semver.gte(yarnVersion, "0.16.0")) {
      return yarnVersion;
    } else {
      return null;
    }
  } catch (error1) {
    err = error1;
    console.error("Cannot parse yarn version: ".concat(yarnVersion));
    return null;
  }
};

init = function (name, opts) {
  validateProjectName(name);

  if (fs.existsSync(name)) {
    return createAfterConfirmation(name, opts);
  } else {
    return createProject(name, opts);
  }
};

run = function (root, projectName, opts) {
  var bootstrapRuuiProject, forceNpmClient, rnCli, rnInit, rnPackage, ruuiPackage, verbose, yarnVersion;
  rnPackage = opts.version;
  verbose = opts.verbose;
  forceNpmClient = opts.npm;
  yarnVersion = !forceNpmClient && getYarnVersionIfAvailable();
  rnPackage = getInstallPackage(rnPackage);
  ruuiPackage = fs.existsSync(path.resolve(process.cwd(), "../../cli.js")) ? "file:".concat(path.resolve(process.cwd(), "../../")) : getInstallPackage("react-universal-ui");
  installPackage(rnPackage, yarnVersion, forceNpmClient, verbose);
  checkNodeVersion();
  rnCli = require(modulePath("react-native", "cli.js"));
  rnInit = rnCli.init(root, projectName, opts);

  bootstrapRuuiProject = function () {
    var defaultAppPath, ruuiInit;
    installPackage(ruuiPackage, yarnVersion, forceNpmClient, verbose); // install react-universal-ui package

    ruuiInit = require(modulePath("react-universal-ui", "lib", "commonjs", "cli", "local", "commands", "init"));
    ruuiInit(root, projectName, opts);
    defaultAppPath = path.resolve(root, "App.js");

    if (fs.existsSync(defaultAppPath)) {
      return fs.unlinkSync(defaultAppPath);
    }
  };

  if (rnInit.then) {
    rnInit.then(function () {
      return bootstrapRuuiProject();
    });
    return rnInit.catch(function (error) {
      return console.log("React Native failed, ".concat(error));
    });
  } else {
    return bootstrapRuuiProject();
  }
};

installPackage = function (packageName, yarnVersion, forceNpmClient, verbose) {
  var err, installCommand;
  installCommand = "";

  if (yarnVersion && !forceNpmClient) {
    console.log("Using yarn v ".concat(yarnVersion, " to install ").concat(packageName));
    installCommand = "yarn add ".concat(packageName, " --exact");
  } else {
    console.log("Consider installing yarn to make this faster: https://yarnpkg.com");
    installCommand = "npm install --save --save-exact ".concat(packageName);
  }

  if (verbose) {
    installCommand += " --verbose";
  }

  try {
    return childProcess.execSync(installCommand, {
      stdio: "inherit"
    });
  } catch (error1) {
    err = error1;
    console.log(err);
    console.error("Command ".concat(installCommand, " failed."));
    return process.exit(1);
  }
};

validateProjectName = function (name) {
  if (!String(name).match(/^[$A-Z_][0-9A-Z_$]*$/i)) {
    console.log(ruuiInvalidProjectName(name)), process.exit(1);
  }

  if (name === "React") {
    console.log(ruuiInvalidProjectKeyword(name));
    return process.exit(1);
  }
};

createAfterConfirmation = function (name, opts) {
  var property;
  prompt.start();
  property = {
    name: "yesno",
    message: "Directory ".concat(name, " already exists. Continue?"),
    validator: /y[es]*|n[o]?/,
    warning: "Must respond yes or no",
    default: "no"
  };
  return prompt.get(property, function (err, result) {
    if (result.yesno[0] === "y") {
      return createProject(name, opts);
    } else {
      console.log("Project initialization canceled");
      return process.exit(1);
    }
  });
};

createProject = function (name, opts) {
  var packageJson, projectName, root;
  root = path.resolve(name);
  projectName = path.basename(root);
  packageJson = {
    name: projectName,
    version: "0.0.1",
    private: true,
    scripts: {
      start: "node node_modules/react-native/local-cli/cli.js start",
      ios: "react-native run-ios",
      android: "react-native run-android"
    }
  };

  if (!fs.existsSync(root)) {
    fs.mkdirSync(root);
  }

  fs.writeFileSync(path.join(root, "package.json"), JSON.stringify(packageJson));
  process.chdir(root);
  return run(root, projectName, opts);
};

getInstallPackage = function (chosenPackage, defaultPackage = "react-native") {
  var isValidSemver, packageToInstall;
  packageToInstall = defaultPackage;
  isValidSemver = semver.valid(chosenPackage);

  if (isValidSemver) {
    packageToInstall = "".concat(defaultPackage, "@").concat(isValidSemver);
  } else if (chosenPackage) {
    packageToInstall = chosenPackage;
  }

  return packageToInstall;
};

checkNodeVersion = function () {
  var invalidEngine, packageJson;
  packageJson = require(packageJsonPath());
  invalidEngine = !semver.satisfies(process.version, packageJson.engines.node);

  if (!packageJson.engines || !packageJson.engines.node) {
    return;
  }

  if (invalidEngine) {
    return console.error(chalk.red(ruuiInvalidNodeVersion(process.version, packageJson.engines.node)));
  }
};

if (cli) {
  cli.run();
} else {
  if (options._.length === 0 && (options.h || options.help)) {
    console.log(ruuiInstruction), process.exit(1);
  }

  if (commands.length === 0) {
    console.log(ruuiNoCommandMessage), process.exit(1);
  }

  switch (commands[0]) {
    case "init":
      if (!commands[1]) {
        console.error(ruuiInitUsage), process.exit(1);
      } else {
        init(commands[1], options);
      }

      break;

    default:
      console.error(ruuiUnrecognizedCommand(commands[0])), process.exit(1);
  }
}
//# sourceMappingURL=ruui.js.map