var appJson, chalk, childProcess, fs, getJson, hydrate, localModule, path, paths, run, ruui, setEnv, webpack, writeFile;
fs = require("fs");
path = require("path");
childProcess = require("child_process");
({
  chalk,
  webpack
} = require("../util/modules"));
({
  paths,
  ruui,
  appJson
} = require("../util/configs"));
({
  localModule,
  setEnv,
  getJson,
  writeFile
} = require("../util/helper"));

run = function (argv, config, args) {
  var compiler, configs;
  setEnv({
    ENV: "production",
    NODE_ENV: "production"
  });
  console.log("Bundling project to ".concat(chalk.magenta(process.env.ENV), " release..."));
  configs = require("../tools/webpack.config")();
  compiler = webpack(configs);
  return compiler.run(function (error, stats) {
    var extendedRuuiJson, indexHtmlPath, keepBuild, keepHtml, lastBuildPath, nodeEntryPath, ruuiJson;

    if (error) {
      return console.log(error);
    } else {
      ruuiJson = getJson(paths.ruuiJson); // lastest version of ruui.json, after build successfully!

      lastBuildPath = path.resolve(paths.ruui, "".concat(ruuiJson.previousBuildId, ".js"));
      indexHtmlPath = path.resolve(paths.ruui, "index.html");
      nodeEntryPath = localModule("index.node.js");
      keepBuild = ruui.keepPreviousBuild;
      keepHtml = ruui.keepHtml;

      if (!keepBuild && ruuiJson.previousBuildId && fs.existsSync(lastBuildPath)) {
        console.log(chalk.gray("clean up previous build, ".concat(chalk.green("deleted"), " ruui/").concat(ruuiJson.previousBuildId, ".js")));
        fs.unlinkSync(lastBuildPath);
      }

      if (!keepHtml && fs.existsSync(nodeEntryPath) && fs.existsSync(indexHtmlPath)) {
        fs.unlinkSync(indexHtmlPath);
      }

      extendedRuuiJson = Object.assign(ruuiJson, {
        previousBuildId: ruuiJson.buildId
      });
      return writeFile(paths.ruuiJson, JSON.stringify(extendedRuuiJson, null, 2), async function () {
        await hydrate(args);
        return console.log("Finished generate static markups!");
      });
    }
  });
};

hydrate = function (args) {
  return new Promise(function (resolve, reject) {
    var babelNodePath, child, error, nodeEntryPath;

    if (args.hydrate) {
      try {
        // start hydrate process..
        console.log("Generate static markups..");
        setEnv({
          ENV: "production",
          HYDRATE: "true",
          NODE_ENV: "production"
        });
        nodeEntryPath = localModule("index.node.js");
        babelNodePath = localModule("node_modules", "@babel", "node", "bin", "babel-node.js");

        if (!fs.existsSync(babelNodePath)) {
          console.log("couldn't locate babel-node module, make sure @babel/node package installed!");
          return;
        }

        child = childProcess.fork(babelNodePath, [nodeEntryPath], {
          cwd: process.cwd(),
          stdio: "inherit"
        });
        return child.on("close", function () {
          return resolve();
        });
      } catch (error1) {
        error = error1;
        return console.log("error during spawn hydrate process\n", error);
      }
    } else {
      return resolve();
    }
  });
};

module.exports = {
  name: "bundle",
  description: "bundle ruui project to production output",
  func: run,
  options: [{
    command: "--hydrate",
    default: ruui.ssrHydrate,
    description: "Hydrate pages to static HTML markup like Gatsby.js"
  }]
};
//# sourceMappingURL=bundle.js.map