var appJson, chalk, childProcess, fs, isPortTaken, launchDevServer, launchSsr, localModule, paths, run, ruui, ruuiJson, setEnv;
fs = require("fs");
childProcess = require("child_process");
({
  chalk
} = require("../util/modules"));
({
  paths,
  ruui,
  ruuiJson,
  appJson
} = require("../util/configs"));
({
  setEnv,
  localModule,
  isPortTaken
} = require("../util/helper"));

run = function (argv, config, args) {
  var devOnly, host, nodeEntryPath, port, ssrPort;
  ({
    port,
    ssrPort,
    host,
    devOnly
  } = args);
  nodeEntryPath = localModule("index.node.js");

  if (!devOnly && fs.existsSync(nodeEntryPath)) {
    launchSsr(nodeEntryPath, host, ssrPort);
  }

  return setTimeout(function () {
    return launchDevServer(host, port);
  }, 1000); // <- it take at least
};

launchSsr = function (nodeEntryPath, host, ssrPort) {
  var babelNodePath, error, port;

  try {
    port = ssrPort || process.env.PORT || 3005; // <- since port will change for Development and Ssr, we must get it again..

    console.log("Preparing node server at http://".concat(host, ":").concat(chalk.gray(port)));
    babelNodePath = localModule("node_modules", "@babel", "node", "bin", "babel-node.js");

    if (!fs.existsSync(babelNodePath)) {
      console.log("couldn't locate babel-node module, make sure @babel/node package installed!");
      return;
    }

    return childProcess.fork(babelNodePath, [nodeEntryPath], {
      cwd: process.cwd(),
      stdio: "inherit"
    });
  } catch (error1) {
    error = error1;
    return console.log("error during spawn ssr-server\n", error);
  }
};

launchDevServer = function (host, port) {
  var devServer;
  setEnv({
    PORT: port
  });
  console.log("Preparing development server at http://".concat(host, ":").concat(chalk.gray(port)));
  devServer = require("../tools/webpack.devserver")();
  return devServer.listen(port, host, function (error, result) {
    if (error) {
      console.log(error);
    }

    return true;
  });
};

module.exports = {
  name: "dev",
  description: "run Development server",
  func: run,
  examples: [{
    desc: "Run on different port, e.g. localhost:2019",
    cmd: "ruui dev --port 2019"
  }, {
    desc: "Run on different host (ip), e.g. 192.168.1.9:3000",
    cmd: "ruui dev --host 192.168.1.9"
  }],
  options: [{
    command: "--port [number]",
    default: ruui.port,
    description: "Specify port for development server",
    parse: function (val) {
      return Number(val);
    }
  }, {
    command: "--ssr-port [number]",
    default: ruui.ssrPort,
    description: "Specify port for sever-side-rendering server",
    parse: function (val) {
      return Number(val);
    }
  }, {
    command: "--host [string]",
    default: ruui.host,
    description: "Specify host for development server"
  }, {
    command: "-d, --devOnly",
    description: "Don't run server-side-rendering server"
  }]
};
//# sourceMappingURL=dev.js.map