var chalk, copyAndReplace, dotFilePath, fs, getDirectories, init, isDirectory, path, ruuiCliModule, ruuiModule, templateExclusions, walk, yarn;
fs = require("fs");
path = require("path");
({
  chalk
} = require("../util/modules"));
({
  ruuiModule,
  ruuiCliModule,
  isDirectory,
  getDirectories,
  dotFilePath,
  templateExclusions
} = require("../util/helper"));
walk = require("../util/walk");
copyAndReplace = require("../util/copyAndReplace");
yarn = require("../util/yarn");

init = function (root, argsOrName, opts) {
  var args, availableTemplates, childDependenciesPath, childDevDependenciesPath, childTemplatePath, coreDependenciesPath, coreDevDependenciesPath, coreTemplatePath, dependencies, devDependencies, newProjectName, template, templateReplacements, templates, yarnVersion;
  template = opts["extends"];
  availableTemplates = getDirectories(path.resolve(ruuiModule("cli", "templates"))).map(function (source) {
    return path.relative(ruuiModule("cli", "templates"), source);
  }).filter(function (name) {
    return name !== "core";
  });
  yarnVersion = !opts.npm && yarn.getYarnVersionIfAvailable() && yarn.isProjectUsingYarn(root);
  templates = require('../util/templates');
  args = Array.isArray(argsOrName) ? argsOrName : [argsOrName].concat(process.argv.slice(4));
  newProjectName = args[0];
  templateReplacements = {
    "Hello App Display Name": newProjectName,
    'HelloWorld': newProjectName,
    'helloworld': newProjectName.toLowerCase()
  };
  dependencies = {};
  devDependencies = {};
  coreTemplatePath = path.resolve(ruuiModule("cli", "templates/core"));
  coreDependenciesPath = path.resolve(coreTemplatePath, "dependencies.json");
  coreDevDependenciesPath = path.resolve(coreTemplatePath, "devDependencies.json");

  if (fs.existsSync(coreDevDependenciesPath)) {
    dependencies = Object.assign(dependencies, require(coreDependenciesPath));
  }

  if (fs.existsSync(coreDevDependenciesPath)) {
    devDependencies = Object.assign(devDependencies, require(coreDevDependenciesPath));
  }

  walk(coreTemplatePath).forEach(function (absoluteSrcPath) {
    var absoluteDestinationPath, relativeFilePath, relativeRenamedPath;
    relativeFilePath = path.relative(coreTemplatePath, absoluteSrcPath);
    relativeRenamedPath = dotFilePath(relativeFilePath);
    absoluteDestinationPath = path.resolve(root, relativeRenamedPath);

    if (templateExclusions.indexOf(relativeRenamedPath) >= 0) {
      return;
    }

    return copyAndReplace(absoluteSrcPath, absoluteDestinationPath, templateReplacements);
  });

  if (template && template !== "core") {
    if (availableTemplates.indexOf(template) >= 0) {
      childTemplatePath = path.resolve(ruuiModule("cli", "templates/".concat(template)));
      childDependenciesPath = path.resolve(childTemplatePath, "dependencies.json");
      childDevDependenciesPath = path.resolve(childTemplatePath, "devDependencies.json");

      if (fs.existsSync(childDependenciesPath)) {
        dependencies = Object.assign(dependencies, require(childDependenciesPath));
      }

      if (fs.existsSync(childDevDependenciesPath)) {
        devDependencies = Object.assign(devDependencies, require(childDevDependenciesPath));
      }

      walk(childTemplatePath).forEach(function (absoluteSrcPath) {
        var absoluteDestinationPath, relativeFilePath, relativeRenamedPath;
        relativeFilePath = path.relative(childTemplatePath, absoluteSrcPath);
        relativeRenamedPath = dotFilePath(relativeFilePath);
        absoluteDestinationPath = path.resolve(root, relativeRenamedPath);

        if (templateExclusions.indexOf(relativeRenamedPath) >= 0) {
          return;
        }

        return copyAndReplace(absoluteSrcPath, absoluteDestinationPath, templateReplacements);
      });
    } else {
      console.log(chalk.yellow("Couldn't found template with name \"".concat(template, "\", used essential template.")));
    }
  }

  templates.installDependencies(dependencies, yarnVersion, false);
  return templates.installDependencies(devDependencies, yarnVersion, true);
};

module.exports = init;
//# sourceMappingURL=init.js.map