var DefinePlugin, HtmlWebpackPlugin, ProgressBarPlugin, ReactRefreshWebpackPlugin, appJson, chalk, defaultConfigs, defaultConfigurator, fs, getJson, localModule, path, paths, ruui, terminalTheme, uuid, webpack, writeFile;
fs = require("fs");
path = require("path");
({
  chalk,
  webpack
} = require("../util/modules"));
HtmlWebpackPlugin = require(path.resolve(process.cwd(), "node_modules", "html-webpack-plugin"));
DefinePlugin = require(path.resolve(process.cwd(), "node_modules", "webpack/lib/DefinePlugin"));
ProgressBarPlugin = require(path.resolve(process.cwd(), "node_modules", "progress-bar-webpack-plugin"));
ReactRefreshWebpackPlugin = require(path.resolve(process.cwd(), "node_modules", "@pmmmwh/react-refresh-webpack-plugin"));
({
  paths,
  ruui,
  appJson
} = require("../util/configs"));
({
  localModule,
  terminalTheme,
  getJson,
  writeFile,
  uuid
} = require("../util/helper"));

defaultConfigurator = function (baseConfig) {
  return baseConfig;
};

defaultConfigs = function () {
  var brightFlag, buildId, entries, env, extendedState, hot, htmlOptions, initialBuild, isProduction, optionalPlugins, polyfills, publicPath, ruuiJson, uniqueId;
  env = ruui.env();
  publicPath = ruui.publicPath(env);
  isProduction = env === "production";
  htmlOptions = {
    isProduction,
    publicPath,
    appName: appJson.displayName || appJson.name || "Ruui Application",
    useVendorChunks: false
  };
  uniqueId = ruui.buildId || uuid;
  buildId = uniqueId();
  optionalPlugins = [];
  polyfills = []; //["babel-polyfill"]

  entries = ["./index.web.js"];
  hot = ["webpack-dev-server/client?".concat(publicPath), "webpack/hot/only-dev-server"];
  brightFlag = false;
  initialBuild = true;

  if (isProduction) {
    ruuiJson = getJson(paths.ruuiJson);
    extendedState = Object.assign(ruuiJson, {
      buildId
    });
    writeFile(paths.ruuiJson, JSON.stringify(extendedState, null, 2));
  } else {
    optionalPlugins.push(new webpack.HotModuleReplacementPlugin());
    optionalPlugins.push(new ReactRefreshWebpackPlugin());
  }

  return {
    context: process.cwd(),
    mode: isProduction ? "production" : "development",
    cache: true,
    entry: {
      app: {
        import: isProduction ? entries : hot.concat(entries),
        filename: isProduction ? "".concat(buildId, ".js") : "[name].js"
      }
    },
    optimization: {
      minimize: isProduction,
      moduleIds: "named"
    },
    output: {
      publicPath: publicPath,
      path: paths.ruui,
      filename: "[name].js",
      sourceMapFilename: isProduction ? "".concat(buildId, ".map") : "[name].map",
      chunkFilename: '[id].js'
    },
    resolve: {
      mainFields: ["browser", "main", "module"],
      alias: {
        "react-native": "react-native-web"
      },
      modules: [localModule("src"), "node_modules"],
      extensions: [".web.js", ".js"]
    },
    module: {
      rules: [{
        test: /\.js?$/,
        loader: 'babel-loader',
        options: {
          compact: false,
          cacheDirectory: true,
          plugins: isProduction ? [] : [require.resolve('react-refresh/babel')]
        }
      }, {
        test: /\.sass$/,
        use: [{
          loader: "style-loader"
        }, {
          loader: "css-loader",
          options: {
            modules: true
          }
        }, {
          loader: "sass-loader"
        }]
      }, {
        test: /\.(png|jpg|svg|ttf)$/,
        loader: "file-loader",
        options: {
          name: "[hash].[ext]"
        }
      }]
    },
    plugins: [new DefinePlugin({
      ENV: JSON.stringify(env),
      'process.env.NODE_ENV': JSON.stringify(env)
    }), new HtmlWebpackPlugin(Object.assign(htmlOptions, ruui.ejsTemplate || {}, {
      template: paths.getEjsTemplate(),
      filename: "index.html"
    })), new ProgressBarPlugin({
      width: 32,
      complete: terminalTheme.progressbar.complete,
      incomplete: terminalTheme.progressbar.remaining,
      format: "building ".concat(terminalTheme.progressbar.prefix, ":bar").concat(terminalTheme.progressbar.suffix, " (:elapsed seconds)"),
      summary: false,
      customSummary: function (buildTime) {
        var alternatedColor, buildFlag, buildType, ruuiBullet, trailingSpace;
        alternatedColor = brightFlag ? function (x) {
          return x;
        } : chalk.gray;
        ruuiBullet = "".concat(terminalTheme.prefix).concat(alternatedColor('ruui')).concat(terminalTheme.suffix);
        buildType = initialBuild ? 'initial build' : 'hot rebuild';
        buildFlag = isProduction ? "production bundle" : buildType;
        trailingSpace = initialBuild ? "" : "  ";
        console.log(ruuiBullet, chalk.gray("".concat(buildFlag, " completed after").concat(trailingSpace)), buildTime);
        brightFlag = !brightFlag;
        return initialBuild = false;
      }
    })].concat(optionalPlugins)
  };
};

module.exports = function () {
  var configurator;
  configurator = ruui.webpack || defaultConfigurator;
  return configurator(defaultConfigs(), webpack);
};
//# sourceMappingURL=webpack.config.js.map