var binaryExtensions, copyAndReplace, copyBinaryFile, fs, path;
fs = require("fs");
path = require("path");
binaryExtensions = [".png", ".jar"];

copyBinaryFile = function (srcPath, destPath, cb) {
  var cbCalled, done, readStream, srcPermissions, writeStream;
  cbCalled = false;

  done = function (err) {
    if (!cbCalled) {
      cb(err);
      return cbCalled = true;
    }
  };

  srcPermissions = fs.statSync(srcPath).mode;
  readStream = fs.createReadStream(srcPath);
  readStream.on('error', function (err) {
    return done(err);
  });
  writeStream = fs.createWriteStream(destPath, {
    mode: srcPermissions
  });
  writeStream.on('error', function (err) {
    return done(err);
  });
  writeStream.on('close', function () {
    return done();
  });
  return readStream.pipe(writeStream);
};

copyAndReplace = function (srcPath, destPath, replacements, contentChangedCallback) {
  var content, contentChanged, err, error, extension, newContentBuffer, origContent, origContentBuffer, shouldOverwrite, srcPermissions;

  if (fs.lstatSync(srcPath).isDirectory()) {
    if (!fs.existsSync(destPath)) {
      fs.mkdirSync(destPath);
    }

    return;
  }

  extension = path.extname(srcPath);

  if (binaryExtensions.indexOf(extension) !== -1) {
    // <- Binary file
    shouldOverwrite = "overwrite";

    if (contentChangedCallback) {
      newContentBuffer = fs.readFileSync(srcPath);
      contentChanged = "identical";

      try {
        origContentBuffer = fs.readFileSync(destPath);

        if (Buffer.compare(origContentBuffer, newContentBuffer) !== 0) {
          contentChanged = "changed";
        }
      } catch (error1) {
        error = error1;

        if (error.code === "ENOENT") {
          contentChanged = "new";
        } else {
          throw err;
        }
      }

      shouldOverwrite = contentChangedCallback(destPath, contentChanged);
    }

    if (shouldOverwrite === "overwrite") {
      // <- Text file
      return copyBinaryFile(srcPath, destPath, function (err) {
        if (err) {
          throw err;
        }
      });
    }
  } else {
    srcPermissions = fs.statSync(srcPath).mode;
    content = fs.readFileSync(srcPath, 'utf8');
    Object.keys(replacements).forEach(function (regex) {
      return content = content.replace(new RegExp(regex, "g"), replacements[regex]);
    });
    shouldOverwrite = "overwrite";

    if (contentChangedCallback) {
      contentChanged = "identical";

      try {
        origContent = fs.readFileSync(destPath, "utf8");

        if (content !== origContent) {
          contentChanged = "changed";
        }
      } catch (error1) {
        err = error1;

        if (err.code === "ENOENT") {
          contentChanged = "new";
        } else {
          throw err;
        }
      }

      shouldOverwrite = contentChangedCallback(destPath, contentChanged);
    }

    if (shouldOverwrite === "overwrite") {
      return fs.writeFileSync(destPath, content, {
        encoding: 'utf8',
        mode: srcPermissions
      });
    }
  }
};

module.exports = copyAndReplace;
//# sourceMappingURL=copyAndReplace.js.map