var defaultPageExtractor, hydrate, pageMarkups, universalRender;
import fs from "fs";
import path from "path";
import { localModule, writeFile } from "./helper";
import configs from "./configs";

pageMarkups = function (AppRegistry, reactDom, initialProps) {
  var element, getStyleElement;
  ({
    element,
    getStyleElement
  } = AppRegistry.getApplication(configs.appJson.name, {
    initialProps,
    rootTag: "root"
  }));
  return {
    initialHtml: reactDom.renderToString(element),
    initialStyles: reactDom.renderToStaticMarkup(getStyleElement())
  };
};

universalRender = function (AppRegistry, reactDom) {
  return function (req, res, next) {
    var env, initialMarkups, initialProps, isProduction, pageTemplate, publicPath;
    env = configs.ruui.env();
    publicPath = configs.ruui.publicPath(env);
    isProduction = env === "production";
    initialProps = {
      ssrLocation: req.baseUrl,
      ssrContext: {}
    };
    initialMarkups = pageMarkups(AppRegistry, reactDom, initialProps);
    pageTemplate = configs.paths.getEjsTemplate();
    return res.render(pageTemplate, {
      ssrContext: Object.assign(initialMarkups, {
        serverSide: true,
        appName: configs.appJson.displayName || configs.appJson.name,
        publicPath: publicPath,
        buildId: configs.ruuiJson.buildId,
        isProduction
      }, configs.ruui.ejsTemplate)
    });
  };
};

defaultPageExtractor = function (routeConfig) {
  var ref;
  return ((ref = routeConfig[0]) != null ? ref.routes : void 0) || [];
};

hydrate = function (AppRegistry, reactDom, routeConfig, pageExtractor = defaultPageExtractor) {
  var ejs, env, fileName, finalMarkups, generateMarkup, i, initialMarkups, isProduction, len, options, page, pageLocation, pageTemplate, pages, publicPath, results, templatePath;
  env = configs.ruui.env();
  publicPath = configs.ruui.publicPath(env);
  ejs = require(localModule("node_modules", "ejs"));
  isProduction = env === "production";
  pages = pageExtractor(routeConfig);
  templatePath = configs.paths.getEjsTemplate();

  if (!fs.existsSync) {
    console.log("can not find page template at ".concat(templatePath));
    return;
  }

  pageTemplate = fs.readFileSync(templatePath, "utf-8");
  generateMarkup = ejs.compile(pageTemplate, {});
  results = [];

  for (i = 0, len = pages.length; i < len; i++) {
    page = pages[i];
    pageLocation = page.path || "/404";
    initialMarkups = pageMarkups(AppRegistry, reactDom, {
      ssrLocation: pageLocation,
      ssrContext: {}
    });
    options = {
      ssrContext: Object.assign(initialMarkups, {
        serverSide: true,
        appName: configs.appJson.displayName || configs.appJson.name,
        publicPath: publicPath,
        buildId: configs.ruuiJson.buildId,
        isProduction
      }, configs.ruui.ejsTemplate)
    };
    finalMarkups = generateMarkup(options);
    fileName = "".concat(pageLocation.replace('/', ''), ".html");

    if (page.path === "/") {
      fileName = "index.html";
    }

    results.push(writeFile(path.resolve(configs.paths.ruui, fileName), finalMarkups));
  }

  return results;
};

module.exports = {
  universalRender,
  pageMarkups,
  hydrate
};
//# sourceMappingURL=ssr.js.map