function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React, { Component } from 'react';
import { Animated, Easing, NetInfo, ActivityIndicator, View, Text, StyleSheet } from 'react-native';
import Button from './button';
import { connect } from '../utils';
import * as appActions from '../utils/store/appAction';

class RuuiConnectionMask extends Component {
  constructor(props) {
    super(props);

    _defineProperty(this, "props", void 0);

    _defineProperty(this, "retry", () => {
      NetInfo.isConnected.fetch().then(isConnected => {
        this.props.dispatch(appActions.updateNetInfo({
          isConnected
        }));
      });
    });

    _defineProperty(this, "playAnimation", (toValue, callback) => {
      if (this.animation) this.animation.clear();
      const easing = toValue === 0 ? Easing.out(Easing.bezier(0, 0, 0.58, 1)) : Easing.in(Easing.bezier(0, 0.48, 0.35, 1)),
            animations = [Animated.timing(this.state.enterAnimation, {
        toValue,
        duration: 500,
        easing,
        useNativeDriver: true
      })];
      this.animation = Animated.parallel(animations).start(callback);
    });

    this.state = {
      enterAnimation: new Animated.Value(0)
    };
  }

  componentDidUpdate(prevProps) {
    const {
      netInfo
    } = this.props;

    if (prevProps.netInfo.isConnected !== netInfo.isConnected) {
      this.playAnimation(netInfo.isConnected ? 0 : 1);
    }
  }

  render() {
    const pointerEvents = this.props.netInfo.isConnected ? 'none' : 'auto',
          opacity = this.state.enterAnimation.interpolate({
      inputRange: [0, 1],
      outputRange: [0, 1]
    }),
          containerStyle = {
      opacity
    };
    return /*#__PURE__*/React.createElement(Animated.View, {
      pointerEvents: pointerEvents,
      style: [styles.container, this.props.wrapperStyle, containerStyle]
    }, this.props.contentRenderer ? this.props.contentRenderer(this.props.netInfo) : /*#__PURE__*/React.createElement(View, {
      style: styles.innerContainer
    }, this.props.message, /*#__PURE__*/React.createElement(ActivityIndicator, {
      color: "#ffffff",
      style: styles.activityIndicator
    }), /*#__PURE__*/React.createElement(Button, {
      title: this.props.retryButtonCaption,
      icon: this.props.retryButtonIcon,
      rightIcon: this.props.retryButtonRightIcon,
      wrapperStyle: this.props.retryButtonWrapperStyle,
      innerStyle: this.props.retryButtonInnerStyle,
      onPress: this.retry
    })));
  }

}

_defineProperty(RuuiConnectionMask, "defaultProps", {
  message: /*#__PURE__*/React.createElement(Text, {
    style: {
      color: '#ffffff',
      fontSize: 20,
      textAlign: 'center'
    }
  }, "App need internet connection, waiting for reconnect.."),
  retryButtonCaption: 'Retry'
});

export default connect(({
  netInfo
}) => {
  return {
    netInfo
  };
})(RuuiConnectionMask);
const styles = StyleSheet.create({
  container: {
    position: 'absolute',
    top: 0,
    left: 0,
    right: 0,
    bottom: 0,
    backgroundColor: 'rgba(0, 0, 0, 0.7)'
  },
  innerContainer: {
    position: 'absolute',
    top: 0,
    left: 0,
    right: 0,
    bottom: 0,
    justifyContent: 'center',
    alignItems: 'center',
    paddingHorizontal: 28
  },
  activityIndicator: {
    marginVertical: 20
  }
});
//# sourceMappingURL=connectionMask.js.map