function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { Animated, Easing, View, StyleSheet } from 'react-native';
import Selector from './selector';
import LoadingMask from './loadingMask';
import CloseableModal from './closeableModal';
import { valueAt } from '../utils';
import * as appActions from '../utils/store/appAction';
export default class RuuiModal extends Component {
  constructor(props) {
    super(props);

    _defineProperty(this, "playAnimation", (toValue, callback) => {
      if (this.animation) this.animation.clear();
      const easing = toValue === 0 ? Easing.out(Easing.bezier(0, 0, 0.58, 1)) : Easing.in(Easing.bezier(0, 0.48, 0.35, 1)),
            animations = [Animated.timing(this.enterAnimation, {
        toValue,
        duration: 500,
        easing,
        useNativeDriver: false
      })];
      this.animation = Animated.parallel(animations).start(callback);
    });

    this.state = {
      active: props.active
    };
    this.enterAnimation = new Animated.Value(0);
  }

  componentDidMount() {
    const {
      active,
      animationDelay
    } = this.props;
    setTimeout(() => this.playTransition(active), animationDelay);
  }

  componentDidUpdate(prevProps) {
    const {
      active
    } = this.props;

    if (prevProps.active !== active) {
      this.playTransition(active);
    }
  }

  playTransition(active) {
    const {
      configs = {}
    } = this.props;
    const nextValue = active ? 1 : 0;

    if (!active) {
      if (configs.instantClose) {
        this.setState({
          active: null
        });
        if (configs.onClose) configs.onClose();
      } else {
        this.playAnimation(nextValue, () => {
          this.setState({
            active: null
          });
          if (configs.onClose) configs.onClose();
        });
      }
    } else {
      this.setState({
        active
      });
      this.playAnimation(nextValue);
    }
  }

  render() {
    const {
      configs = {},
      modalCount,
      type: modalType
    } = this.props,
          {
      active
    } = this.state,
          globalConfigs = valueAt(this, 'context.ruuiConfigs.modal'),
          containerPropsGenerator = configs.maskProps || globalConfigs.maskProps,
          containerProps = containerPropsGenerator(this.enterAnimation, configs, modalCount, modalType);

    if (configs.maskProps && !containerProps.style) {
      containerProps.style = globalConfigs.maskProps(this.enterAnimation, configs, modalCount, modalType).style;
    }

    return active ? /*#__PURE__*/React.createElement(Animated.View, containerProps, /*#__PURE__*/React.createElement(View, {
      style: styles.innerTouchable
    }, this.renderModalInner())) : /*#__PURE__*/React.createElement(View, null);
  }

  renderModalInner() {
    const {
      dispatch,
      type: modalType,
      active,
      configs: modalConfigs
    } = this.props;

    switch (modalType) {
      case 'select':
        return /*#__PURE__*/React.createElement(Selector, {
          onRequestClose: configs => dispatch(appActions.toggleSelector(false, configs)),
          animation: this.enterAnimation,
          active: active,
          configs: modalConfigs
        });

      case 'modal':
        return /*#__PURE__*/React.createElement(CloseableModal, {
          onRequestClose: configs => dispatch(appActions.toggleModal(false, configs)),
          animation: this.enterAnimation,
          active: active,
          configs: modalConfigs
        });

      case 'loading':
        return /*#__PURE__*/React.createElement(LoadingMask, {
          animation: this.enterAnimation,
          active: active,
          configs: modalConfigs
        });

      default:
        return /*#__PURE__*/React.createElement(View, null);
    }
  }

}

_defineProperty(RuuiModal, "props", void 0);

_defineProperty(RuuiModal, "contextTypes", {
  ruuiConfigs: PropTypes.object
});

export function defaultMaskPropsGenerator(animation, configs, modalCount, modalType) {
  const averageOpacity = 0.8 / modalCount + modalCount * 0.1,
        backgroundColor = animation.interpolate({
    inputRange: [0, 1],
    outputRange: ['rgba(0, 0, 0, 0)', "rgba(0, 0, 0, ".concat(averageOpacity, ")")]
  }),
        style = [styles.container, {
    zIndex: configs.zIndex,
    backgroundColor
  }];
  return {
    style
  };
}
const styles = StyleSheet.create({
  container: {
    position: 'absolute',
    top: 0,
    left: 0,
    right: 0,
    bottom: 0
  },
  innerTouchable: {
    flex: 1
  },
  touchableMask: {
    position: 'absolute',
    top: 0,
    right: 0,
    left: 0,
    bottom: 0
  }
});
//# sourceMappingURL=modal.js.map