function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { TouchableOpacity, Image, View, Text, StyleSheet } from 'react-native';
import { base64Icons } from '../utils';
import { Style } from '../typeDefinition';
import * as appAction from '../utils/store/appAction';
const defaultIcon = {
  uri: base64Icons.downArrow
};

const defaultTitleGet = item => item && item.title;

export default class RuuiSelect extends Component {
  constructor(props, context) {
    super(props);

    _defineProperty(this, "activateSelector", () => {
      const {
        floatingLabel,
        value,
        ...otherProps
      } = this.props;
      this.store.dispatch(appAction.toggleSelector(true, {
        selectText: floatingLabel,
        activeOption: value,
        value,
        ...otherProps
      }));
    });

    this.store = context.ruuiStore;
  }

  render() {
    const {
      iconSource = defaultIcon,
      floatingLabel,
      iconStyle
    } = this.props;
    return /*#__PURE__*/React.createElement(TouchableOpacity, {
      onPress: this.activateSelector,
      style: styles.container,
      activeOpacity: 0.8
    }, /*#__PURE__*/React.createElement(View, {
      style: styles.contentWrapper
    }, /*#__PURE__*/React.createElement(Text, {
      style: styles.floatingLabel
    }, floatingLabel), this.renderValue()), /*#__PURE__*/React.createElement(View, {
      style: styles.iconWrapper
    }, /*#__PURE__*/React.createElement(Image, {
      style: [styles.downIcon, iconStyle],
      resizeMode: "contain",
      source: iconSource
    })));
  }

  renderValue() {
    const {
      value,
      getTitle
    } = this.props,
          valueText = getTitle(value) || 'Missing value option';
    return /*#__PURE__*/React.createElement(Text, {
      style: styles.valueText
    }, valueText);
  }

}

_defineProperty(RuuiSelect, "props", void 0);

_defineProperty(RuuiSelect, "contextTypes", {
  ruuiStore: PropTypes.object
});

_defineProperty(RuuiSelect, "defaultProps", {
  floatingLabel: 'Select',
  cancelText: 'Cancel',
  options: [{
    title: 'Missing options param'
  }],
  tapToClose: true,
  getTitle: defaultTitleGet
});

const styles = StyleSheet.create({
  container: {
    flexDirection: 'row',
    borderBottomWidth: 1,
    borderColor: '#f5f5f5'
  },
  contentWrapper: {
    flex: 1
  },
  floatingLabel: {
    color: '#888888',
    fontSize: 12,
    paddingLeft: 8,
    paddingRight: 8,
    paddingTop: 5
  },
  valueText: {
    padding: 8,
    paddingTop: 8,
    paddingBottom: 5,
    color: '#444444',
    fontSize: 16
  },
  iconWrapper: {
    width: 50,
    justifyContent: 'center',
    alignItems: 'center'
  },
  downIcon: {
    width: 16,
    height: 16
  }
});
//# sourceMappingURL=select.js.map