function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/* eslint-disable */
import React, { PureComponent } from "react";
import { Animated, Image, StyleSheet, PanResponder, View, Easing } from "react-native";
import { isAndroid } from '../utils';
import { Style } from '../typeDefinition';
const TRACK_SIZE = 4,
      THUMB_SIZE = 20;

function Rect(x, y, width, height) {
  this.x = x;
  this.y = y;
  this.width = width;
  this.height = height;
}

Rect.prototype.containsPoint = function (x, y) {
  return x >= this.x && y >= this.y && x <= this.x + this.width && y <= this.y + this.height;
};

const DEFAULT_ANIMATION_CONFIGS = {
  spring: {
    friction: 7,
    tension: 100
  },
  timing: {
    duration: 150,
    easing: Easing.inOut(Easing.ease),
    delay: 0
  } // decay : { // This has a serious bug
  //   velocity     : 1,
  //   deceleration : 0.997
  // }

};
export default class Slider extends PureComponent {
  constructor(...args) {
    super(...args);

    _defineProperty(this, "props", void 0);

    _defineProperty(this, "state", {
      containerSize: {
        width: 0,
        height: 0
      },
      trackSize: {
        width: 0,
        height: 0
      },
      thumbSize: {
        width: 0,
        height: 0
      },
      allMeasured: false,
      value: new Animated.Value(this.props.value)
    });

    _defineProperty(this, "_handleStartShouldSetPanResponder", e => {
      // Should we become active when the user presses down on the thumb?
      return this._thumbHitTest(e);
    });

    _defineProperty(this, "_handlePanResponderGrant", () =>
    /*e: Object, gestureState: Object*/
    {
      this._previousLeft = this._getThumbLeft(this._getCurrentValue());

      this._fireChangeEvent('onSlidingStart');
    });

    _defineProperty(this, "_handlePanResponderMove", (e, gestureState) => {
      if (this.props.disabled) {
        return;
      }

      this._setCurrentValue(this._getValue(gestureState));

      this._fireChangeEvent('onValueChange');
    });

    _defineProperty(this, "_handlePanResponderEnd", (e, gestureState) => {
      if (this.props.disabled) {
        return;
      }

      this._setCurrentValue(this._getValue(gestureState));

      this._fireChangeEvent('onSlidingComplete');
    });

    _defineProperty(this, "_measureContainer", x => {
      this._handleMeasure('containerSize', x);
    });

    _defineProperty(this, "_measureTrack", x => {
      this._handleMeasure('trackSize', x);
    });

    _defineProperty(this, "_measureThumb", x => {
      this._handleMeasure('thumbSize', x);
    });

    _defineProperty(this, "_handleMeasure", (name, x) => {
      const {
        width,
        height
      } = x.nativeEvent.layout;
      const size = {
        width: width,
        height: height
      };
      const storeName = "_".concat(name);
      const currentSize = this[storeName];

      if (currentSize && width === currentSize.width && height === currentSize.height) {
        return;
      }

      this[storeName] = size;

      if (this._containerSize && this._trackSize && this._thumbSize) {
        this.setState({
          containerSize: this._containerSize,
          trackSize: this._trackSize,
          thumbSize: this._thumbSize,
          allMeasured: true
        });
      }
    });

    _defineProperty(this, "_getRatio", value => {
      return (value - this.props.minimumValue) / (this.props.maximumValue - this.props.minimumValue);
    });

    _defineProperty(this, "_getThumbLeft", value => {
      const ratio = this._getRatio(value);

      return ratio * (this.state.containerSize.width - this.state.thumbSize.width);
    });

    _defineProperty(this, "_getValue", gestureState => {
      const length = this.state.containerSize.width - this.state.thumbSize.width;
      const thumbLeft = this._previousLeft + gestureState.dx;
      const ratio = thumbLeft / length;

      if (this.props.step) {
        return Math.max(this.props.minimumValue, Math.min(this.props.maximumValue, this.props.minimumValue + Math.round(ratio * (this.props.maximumValue - this.props.minimumValue) / this.props.step) * this.props.step));
      } else {
        return Math.max(this.props.minimumValue, Math.min(this.props.maximumValue, ratio * (this.props.maximumValue - this.props.minimumValue) + this.props.minimumValue));
      }
    });

    _defineProperty(this, "_getCurrentValue", () => {
      return this.state.value.__getValue();
    });

    _defineProperty(this, "_setCurrentValue", value => {
      this.state.value.setValue(value);
    });

    _defineProperty(this, "_setCurrentValueAnimated", value => {
      const animationType = this.props.animationType;
      const animationConfig = Object.assign({}, DEFAULT_ANIMATION_CONFIGS[animationType], this.props.animationConfig, {
        toValue: value
      });
      Animated[animationType](this.state.value, animationConfig).start();
    });

    _defineProperty(this, "_fireChangeEvent", event => {
      if (this.props[event]) {
        this.props[event](this._getCurrentValue());
      }
    });

    _defineProperty(this, "_getTouchOverflowSize", () => {
      const state = this.state;
      const props = this.props;
      const size = {};

      if (state.allMeasured === true) {
        size.width = Math.max(0, props.thumbTouchSize.width - state.thumbSize.width);
        size.height = Math.max(0, props.thumbTouchSize.height - state.containerSize.height);
      }

      return size;
    });

    _defineProperty(this, "_getTouchOverflowStyle", () => {
      const {
        width,
        height
      } = this._getTouchOverflowSize();

      const touchOverflowStyle = {};

      if (width !== undefined && height !== undefined) {
        const verticalMargin = -height / 2;
        touchOverflowStyle.marginTop = verticalMargin;
        touchOverflowStyle.marginBottom = verticalMargin;
        const horizontalMargin = -width / 2;
        touchOverflowStyle.marginLeft = horizontalMargin;
        touchOverflowStyle.marginRight = horizontalMargin;
      }

      if (this.props.debugTouchArea === true) {
        touchOverflowStyle.backgroundColor = 'orange';
        touchOverflowStyle.opacity = 0.5;
      }

      return touchOverflowStyle;
    });

    _defineProperty(this, "_thumbHitTest", e => {
      const nativeEvent = e.nativeEvent;

      const thumbTouchRect = this._getThumbTouchRect();

      return thumbTouchRect.containsPoint(nativeEvent.locationX, nativeEvent.locationY);
    });

    _defineProperty(this, "_getThumbTouchRect", () => {
      const state = this.state;
      const props = this.props;

      const touchOverflowSize = this._getTouchOverflowSize();

      return new Rect(touchOverflowSize.width / 2 + this._getThumbLeft(this._getCurrentValue()) + (state.thumbSize.width - props.thumbTouchSize.width) / 2, touchOverflowSize.height / 2 + (state.containerSize.height - props.thumbTouchSize.height) / 2, props.thumbTouchSize.width, props.thumbTouchSize.height);
    });

    _defineProperty(this, "_renderDebugThumbTouchRect", thumbLeft => {
      const thumbTouchRect = this._getThumbTouchRect();

      const positionStyle = {
        left: thumbLeft,
        top: thumbTouchRect.y,
        width: thumbTouchRect.width,
        height: thumbTouchRect.height
      };
      return /*#__PURE__*/React.createElement(Animated.View, {
        style: [defaultStyles.debugThumbTouchArea, positionStyle],
        pointerEvents: "none"
      });
    });

    _defineProperty(this, "_renderThumbImage", () => {
      const {
        thumbImage
      } = this.props;
      if (!thumbImage) return;
      return /*#__PURE__*/React.createElement(Image, {
        source: thumbImage
      });
    });
  }

  componentWillMount() {
    this._panResponder = PanResponder.create({
      onStartShouldSetPanResponder: this._handleStartShouldSetPanResponder,
      onMoveShouldSetPanResponder: this._handleMoveShouldSetPanResponder,
      onPanResponderGrant: this._handlePanResponderGrant,
      onPanResponderMove: this._handlePanResponderMove,
      onPanResponderRelease: this._handlePanResponderEnd,
      onPanResponderTerminationRequest: this._handlePanResponderRequestEnd,
      onPanResponderTerminate: this._handlePanResponderEnd
    });
  }

  componentDidUpdate(prevProps) {
    const {
      value,
      animateTransitions
    } = this.props;

    if (prevProps.value !== value) {
      if (animateTransitions) {
        this._setCurrentValueAnimated(value);
      } else {
        this._setCurrentValue(value);
      }
    }
  }

  render() {
    const {
      minimumValue,
      maximumValue,
      minimumTrackTintColor,
      maximumTrackTintColor,
      thumbTintColor,
      thumbImage,
      thumbTouchSize,
      animationType,
      onValueChange,
      styles,
      style,
      trackStyle,
      thumbStyle,
      debugTouchArea,
      ...other
    } = this.props;
    const {
      value,
      containerSize,
      trackSize,
      thumbSize,
      allMeasured
    } = this.state;
    const mainStyles = styles || defaultStyles;
    const thumbLeft = value.interpolate({
      inputRange: [minimumValue, maximumValue],
      outputRange: [0, containerSize.width - thumbSize.width] //extrapolate: 'clamp',

    });
    const valueVisibleStyle = {};

    if (!allMeasured) {
      valueVisibleStyle.opacity = 0;
    }

    const minimumTrackStyle = {
      position: 'absolute',
      width: Animated.add(thumbLeft, thumbSize.width / 2),
      backgroundColor: minimumTrackTintColor,
      ...valueVisibleStyle
    };

    const touchOverflowStyle = this._getTouchOverflowStyle();

    const androidViewProps = isAndroid ? {
      renderToHardwareTextureAndroid: true
    } : {};
    return /*#__PURE__*/React.createElement(View, _extends({}, other, {
      style: [mainStyles.container, style],
      onLayout: this._measureContainer
    }), /*#__PURE__*/React.createElement(View, _extends({
      style: [{
        backgroundColor: maximumTrackTintColor
      }, mainStyles.track, trackStyle]
    }, androidViewProps, {
      onLayout: this._measureTrack
    })), /*#__PURE__*/React.createElement(Animated.View, _extends({}, androidViewProps, {
      style: [mainStyles.track, trackStyle, minimumTrackStyle]
    })), /*#__PURE__*/React.createElement(Animated.View, _extends({
      id: this.props.thumbId,
      onLayout: this._measureThumb
    }, androidViewProps, {
      style: [{
        backgroundColor: thumbTintColor
      }, mainStyles.thumb, thumbStyle, {
        transform: [{
          translateX: thumbLeft
        }, {
          translateY: 0
        }],
        ...valueVisibleStyle
      }]
    }), this._renderThumbImage()), /*#__PURE__*/React.createElement(View, _extends({}, androidViewProps, {
      style: [defaultStyles.touchArea, touchOverflowStyle]
    }, this._panResponder.panHandlers), debugTouchArea === true && this._renderDebugThumbTouchRect(thumbLeft)));
  }

  _getPropsForComponentUpdate(props) {
    const {
      value,
      onValueChange,
      onSlidingStart,
      onSlidingComplete,
      style,
      trackStyle,
      thumbStyle,
      ...otherProps
    } = props;
    return otherProps;
  }

  _handleMoveShouldSetPanResponder() {
    // Should we become active when the user moves a touch over the thumb?
    return false;
  }

  _handlePanResponderRequestEnd(e, gestureState) {
    // Should we allow another component to take over this pan?
    return false;
  }

}

_defineProperty(Slider, "defaultProps", {
  value: 0,
  minimumValue: 0,
  maximumValue: 1,
  step: 0,
  minimumTrackTintColor: '#3f3f3f',
  maximumTrackTintColor: '#b3b3b3',
  thumbTintColor: '#343434',
  thumbTouchSize: {
    width: 40,
    height: 40
  },
  debugTouchArea: false,
  animationType: 'timing'
});

const defaultStyles = StyleSheet.create({
  container: {
    height: 40,
    justifyContent: 'center'
  },
  track: {
    height: TRACK_SIZE,
    borderRadius: TRACK_SIZE / 2
  },
  thumb: {
    position: 'absolute',
    width: THUMB_SIZE,
    height: THUMB_SIZE,
    borderRadius: THUMB_SIZE / 2
  },
  touchArea: {
    position: 'absolute',
    backgroundColor: 'transparent',
    top: 0,
    left: 0,
    right: 0,
    bottom: 0
  },
  debugThumbTouchArea: {
    position: 'absolute',
    backgroundColor: 'green',
    opacity: 0.5
  }
});
//# sourceMappingURL=slider.js.map