function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { shallowEqual } from './helpers';
export function createStore(reducer) {
  let state,
      listeners = [];

  const getState = () => state;

  const getListeners = () => listeners;

  const dispatch = action => {
    state = reducer(state, action);
    listeners.forEach(listener => listener(state));
  };

  const subscribe = listener => {
    listeners.push(listener);
    return () => {
      listeners = listeners.filter(l => l !== listener);
    };
  };

  dispatch({});
  return {
    getState,
    dispatch,
    subscribe,
    getListeners
  };
}
export function combineReducers(reducers) {
  const reducerKeys = Object.keys(reducers);
  return (state = {}, action) => {
    let hasChanged = false;
    const nextState = {};

    for (let i = 0; i < reducerKeys.length; i += 1) {
      const key = reducerKeys[i],
            reducer = reducers[key],
            previousStateForKey = state[key],
            nextStateForKey = reducer(previousStateForKey, action);
      nextState[key] = nextStateForKey;
      hasChanged = hasChanged || nextStateForKey !== previousStateForKey;
    }

    return hasChanged ? nextState : state;
  };
}
export function connect(stateToPropsFactory) {
  return function (BaseComponent) {
    var _class, _temp;

    const currentDisplayName = BaseComponent.displayName || BaseComponent.name,
          enhancedDisplayName = "RuuiConnect(".concat(currentDisplayName, ")");
    return _temp = _class = class RuuiConnected extends Component {
      constructor(props, context) {
        super(props);

        _defineProperty(this, "syncProps", () => {
          const {
            generatedProps
          } = this.state,
                nextProps = stateToPropsFactory(this.store.getState());

          if (!shallowEqual(generatedProps, nextProps)) {
            this.setState({
              generatedProps: nextProps
            });
          }
        });

        this.store = context.ruuiStore;
        this.unSubscribe = this.store.subscribe(this.syncProps);
        this.state = {
          generatedProps: stateToPropsFactory(this.store.getState())
        };
      }

      componentWillUnmount() {
        this.unSubscribe();
      }

      render() {
        const {
          generatedProps
        } = this.state,
              {
          dispatch
        } = this.store;
        return /*#__PURE__*/React.createElement(BaseComponent, _extends({}, this.props, generatedProps, {
          dispatch: dispatch
        }));
      }

    }, _defineProperty(_class, "displayName", enhancedDisplayName), _defineProperty(_class, "contextTypes", {
      ruuiStore: PropTypes.object
    }), _temp;
  };
}
//# sourceMappingURL=ruuiStore.js.map